Array(extent, dtype, locn)
##########################

.. doxygenfunction:: librapid::Array::Array(const Extent &extent, Datatype dtype = Datatype::FLOAT64, Accelerator location = Accelerator::CPU)
.. doxygenfunction:: librapid::Array::Array(const Extent &extent, const std::string& dtype, Accelerator location = Accelerator::CPU)
.. doxygenfunction:: librapid::Array::Array(const Extent &extent, Datatype dtype, const std::string &accelerator = "cpu")
.. doxygenfunction:: librapid::Array::Array(const Extent &extent, const std::string &dtype, const std::string &accelerator)
